var namespaceSteinberg =
[
    [ "FUnknownImpl", "namespaceSteinberg_1_1FUnknownImpl.html", "namespaceSteinberg_1_1FUnknownImpl" ],
    [ "FUnknownPrivate", "namespaceSteinberg_1_1FUnknownPrivate.html", [
      [ "atomicAdd", "namespaceSteinberg_1_1FUnknownPrivate.html#aeab173beb18bb16a5737f9fbe0a45289", null ],
      [ "iidEqual", "namespaceSteinberg_1_1FUnknownPrivate.html#afbf1ba7f286964b19e55474c2905eae4", null ]
    ] ],
    [ "GeoConstants", "namespaceSteinberg_1_1GeoConstants.html", [
      [ "toOpposite", "namespaceSteinberg_1_1GeoConstants.html#aad3372dfdeb4f43befc9a773e13a4ab8", null ],
      [ "toOrientation", "namespaceSteinberg_1_1GeoConstants.html#a708700c46dec5f179f1d6552c7803e84", null ],
      [ "toOrthogonalOrientation", "namespaceSteinberg_1_1GeoConstants.html#a9d80537f969e17e0c06c973409b52bfd", null ]
    ] ],
    [ "KeyCodes", "namespaceSteinberg_1_1KeyCodes.html", [
      [ "isModifierOnlyKey", "namespaceSteinberg_1_1KeyCodes.html#a1411be7b25f47e89beedadd3de3ade07", null ]
    ] ],
    [ "Linux", "namespaceSteinberg_1_1Linux.html", "namespaceSteinberg_1_1Linux" ],
    [ "U", "namespaceSteinberg_1_1U.html", "namespaceSteinberg_1_1U" ],
    [ "ConstStringTable", "classSteinberg_1_1ConstStringTable.html", "classSteinberg_1_1ConstStringTable" ],
    [ "FReleaser", "structSteinberg_1_1FReleaser.html", "structSteinberg_1_1FReleaser" ],
    [ "FUID", "classSteinberg_1_1FUID.html", "classSteinberg_1_1FUID" ],
    [ "FUnknown", "classSteinberg_1_1FUnknown.html", "classSteinberg_1_1FUnknown" ],
    [ "FUnknownPtr", "classSteinberg_1_1FUnknownPtr.html", "classSteinberg_1_1FUnknownPtr" ],
    [ "FVariant", "classSteinberg_1_1FVariant.html", "classSteinberg_1_1FVariant" ],
    [ "IAttributes", "classSteinberg_1_1IAttributes.html", "classSteinberg_1_1IAttributes" ],
    [ "IAttributes2", "classSteinberg_1_1IAttributes2.html", "classSteinberg_1_1IAttributes2" ],
    [ "IBStream", "classSteinberg_1_1IBStream.html", "classSteinberg_1_1IBStream" ],
    [ "ICloneable", "classSteinberg_1_1ICloneable.html", "classSteinberg_1_1ICloneable" ],
    [ "IDependent", "classSteinberg_1_1IDependent.html", "classSteinberg_1_1IDependent" ],
    [ "IErrorContext", "classSteinberg_1_1IErrorContext.html", "classSteinberg_1_1IErrorContext" ],
    [ "IPersistent", "classSteinberg_1_1IPersistent.html", "classSteinberg_1_1IPersistent" ],
    [ "IPlugFrame", "classSteinberg_1_1IPlugFrame.html", "classSteinberg_1_1IPlugFrame" ],
    [ "IPluginBase", "classSteinberg_1_1IPluginBase.html", "classSteinberg_1_1IPluginBase" ],
    [ "IPluginCompatibility", "classSteinberg_1_1IPluginCompatibility.html", "classSteinberg_1_1IPluginCompatibility" ],
    [ "IPluginFactory", "classSteinberg_1_1IPluginFactory.html", "classSteinberg_1_1IPluginFactory" ],
    [ "IPluginFactory2", "classSteinberg_1_1IPluginFactory2.html", "classSteinberg_1_1IPluginFactory2" ],
    [ "IPluginFactory3", "classSteinberg_1_1IPluginFactory3.html", "classSteinberg_1_1IPluginFactory3" ],
    [ "IPlugView", "classSteinberg_1_1IPlugView.html", "classSteinberg_1_1IPlugView" ],
    [ "IPlugViewContentScaleSupport", "classSteinberg_1_1IPlugViewContentScaleSupport.html", "classSteinberg_1_1IPlugViewContentScaleSupport" ],
    [ "IPtr", "classSteinberg_1_1IPtr.html", "classSteinberg_1_1IPtr" ],
    [ "ISizeableStream", "classSteinberg_1_1ISizeableStream.html", "classSteinberg_1_1ISizeableStream" ],
    [ "IString", "classSteinberg_1_1IString.html", "classSteinberg_1_1IString" ],
    [ "IStringResult", "classSteinberg_1_1IStringResult.html", "classSteinberg_1_1IStringResult" ],
    [ "IUpdateHandler", "classSteinberg_1_1IUpdateHandler.html", "classSteinberg_1_1IUpdateHandler" ],
    [ "KeyCode", "structSteinberg_1_1KeyCode.html", "structSteinberg_1_1KeyCode" ],
    [ "OPtr", "classSteinberg_1_1OPtr.html", "classSteinberg_1_1OPtr" ],
    [ "PClassInfo", "structSteinberg_1_1PClassInfo.html", "structSteinberg_1_1PClassInfo" ],
    [ "PClassInfo2", "structSteinberg_1_1PClassInfo2.html", "structSteinberg_1_1PClassInfo2" ],
    [ "PClassInfoW", "structSteinberg_1_1PClassInfoW.html", "structSteinberg_1_1PClassInfoW" ],
    [ "PFactoryInfo", "structSteinberg_1_1PFactoryInfo.html", "structSteinberg_1_1PFactoryInfo" ],
    [ "UString", "classSteinberg_1_1UString.html", "classSteinberg_1_1UString" ],
    [ "UStringBuffer", "classSteinberg_1_1UStringBuffer.html", "classSteinberg_1_1UStringBuffer" ],
    [ "ViewRect", "structSteinberg_1_1ViewRect.html", "structSteinberg_1_1ViewRect" ],
    [ "int8", "namespaceSteinberg.html#ae47c588f3ab8c61121c1c7ab7edc47cd", null ],
    [ "uint8", "namespaceSteinberg.html#a33a5e996e7a90acefb8b1c0bea47e365", null ],
    [ "uchar", "namespaceSteinberg.html#a65f85814a8290f9797005d3b28e7e5fc", null ],
    [ "int16", "namespaceSteinberg.html#aa0d0fdc87fd135ef2bedb030901cdb9c", null ],
    [ "uint16", "namespaceSteinberg.html#ac2a9e79eb120216f855626495b7bd18a", null ],
    [ "int32", "namespaceSteinberg.html#ab7903878916593daecbeb95b98115ab0", null ],
    [ "uint32", "namespaceSteinberg.html#acbd4acd0d29e2d6c43104827f77d9cd2", null ],
    [ "int64", "namespaceSteinberg.html#a7cde0074dfd288f2d70c0e035dacb28a", null ],
    [ "uint64", "namespaceSteinberg.html#abc0f5bc07737e498f287334775dff2b6", null ],
    [ "TSize", "namespaceSteinberg.html#abc5a03f91bd781b5062f4fccaa7851f0", null ],
    [ "tresult", "namespaceSteinberg.html#a902761e005a6252e538c766de48fc957", null ],
    [ "TPtrInt", "namespaceSteinberg.html#adbdfa470c35e7bf57d7952f0767bbf57", null ],
    [ "TBool", "namespaceSteinberg.html#a1ea8addd740f35d207a1569dd38ef895", null ],
    [ "char8", "namespaceSteinberg.html#ac9e1c0f508ae0f5f8a2b704a91e1ae86", null ],
    [ "char16", "namespaceSteinberg.html#a667a0a4e0cbcb3f3785984955e1fefd8", null ],
    [ "char", "namespaceSteinberg.html#aa9eb7d301130a7771343735bef461579", null ],
    [ "CStringA", "namespaceSteinberg.html#a435992556581fbc31a9bddb3bb2f787a", null ],
    [ "CStringW", "namespaceSteinberg.html#a81b4df0e8189d2f135f25919a6a90be2", null ],
    [ "CString", "namespaceSteinberg.html#a6f37e0dbf8faed21d2658800d9db4583", null ],
    [ "FIDString", "namespaceSteinberg.html#ad4c02134d1ee42389f3d94717935a1d5", null ],
    [ "UCoord", "namespaceSteinberg.html#abf33a8b245f4634965116e9c25eb702a", null ],
    [ "LARGE_INT", "namespaceSteinberg.html#a9cd1730908299276af7bc0baa8c5197e", null ],
    [ "TUID", "namespaceSteinberg.html#a6935af93744bfe4ecc455f274ef1ec36", null ],
    [ "IAttrID", "namespaceSteinberg.html#ae6eacc17e4382538d4af0d9993bc869a", null ],
    [ "ColorSpec", "namespaceSteinberg.html#a5b13d028fba1eee386ec9ac208c6238d", null ],
    [ "ColorComponent", "namespaceSteinberg.html#af1189c83b63820c6ccc3167402601fea", null ],
    [ "UColorSpec", "namespaceSteinberg.html#a87699df6cd24276f34afea51d903c6e4", null ],
    [ "UColorComponent", "namespaceSteinberg.html#a3c4f7362f2f494a4120d7c864dd0822d", null ],
    [ "UString128", "namespaceSteinberg.html#aa92186fdeda699e7a0cc7ac6c45d07e5", null ],
    [ "UString256", "namespaceSteinberg.html#a71098a25fa252b10d271a11807153385", null ],
    [ "Direction", "namespaceSteinberg.html#a224b9163917ac32fc95a60d8c1eec3aa", [
      [ "kNorth", "namespaceSteinberg.html#a224b9163917ac32fc95a60d8c1eec3aaa89c5f7af4c1a4fe20ab7524369050200", null ],
      [ "kNorthEast", "namespaceSteinberg.html#a224b9163917ac32fc95a60d8c1eec3aaa80a10c4928ef7af3ce487d381e2420d2", null ],
      [ "kEast", "namespaceSteinberg.html#a224b9163917ac32fc95a60d8c1eec3aaa37d01669db016bc15ed6fdab6fb6c790", null ],
      [ "kSouthEast", "namespaceSteinberg.html#a224b9163917ac32fc95a60d8c1eec3aaadf50c366ce2690678d0e6290f52b4639", null ],
      [ "kSouth", "namespaceSteinberg.html#a224b9163917ac32fc95a60d8c1eec3aaa515c12ec206b53ce5da86a402b3f4cf8", null ],
      [ "kSouthWest", "namespaceSteinberg.html#a224b9163917ac32fc95a60d8c1eec3aaa6a77137c947ac754a97274617a22afb6", null ],
      [ "kWest", "namespaceSteinberg.html#a224b9163917ac32fc95a60d8c1eec3aaa45b705ff067984bfd99c234d91386792", null ],
      [ "kNorthWest", "namespaceSteinberg.html#a224b9163917ac32fc95a60d8c1eec3aaaa67fc18f8f8b0ba3b792b46a1fa0c872", null ],
      [ "kNoDirection", "namespaceSteinberg.html#a224b9163917ac32fc95a60d8c1eec3aaa87e054da76bada3343762974c988e80a", null ],
      [ "kNumberOfDirections", "namespaceSteinberg.html#a224b9163917ac32fc95a60d8c1eec3aaabdba6353397f1b1654328de91f17e348", null ]
    ] ],
    [ "Orientation", "namespaceSteinberg.html#a871118a09520247c78a71ecd7b0abd58", [
      [ "kHorizontal", "namespaceSteinberg.html#a871118a09520247c78a71ecd7b0abd58ad4149164ae4bf90011d92a3dbfcce742", null ],
      [ "kVertical", "namespaceSteinberg.html#a871118a09520247c78a71ecd7b0abd58a4764485d9d221af213bf2b2769cdfc54", null ],
      [ "kNumberOfOrientations", "namespaceSteinberg.html#a871118a09520247c78a71ecd7b0abd58a231632c3d1e6d53428167283534f1abe", null ]
    ] ],
    [ "VirtualKeyCodes", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22b", [
      [ "KEY_BACK", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba363a5589e96b18dca6534e951baffdd3", null ],
      [ "KEY_TAB", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba60c75f9c8eded88ef76c0c94da27963c", null ],
      [ "KEY_CLEAR", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22baee7181a798c5753153051c0e1ace41c9", null ],
      [ "KEY_RETURN", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22baaefd064b1e5d75c429bed314ac18eba0", null ],
      [ "KEY_PAUSE", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22bad26d172dc2cd90741c3939ca4fab0b84", null ],
      [ "KEY_ESCAPE", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba3a471c8b61a5f730dcbdd50fe53f3ab7", null ],
      [ "KEY_SPACE", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba01d2889f9a7550008ad6140c41e733de", null ],
      [ "KEY_NEXT", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba82d61b2ebb1c5fee25aea8d69d325acc", null ],
      [ "KEY_END", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22baa8adb6fcb92dec58fb19410eacfdd403", null ],
      [ "KEY_HOME", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22bad5b83418c285e43af5d3a87b4d4049d7", null ],
      [ "KEY_LEFT", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba612120b69c7dfd46086db7aaebdbcf65", null ],
      [ "KEY_UP", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba0848a442d907968b211b97bc2bd88acd", null ],
      [ "KEY_RIGHT", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba6504370d9c6391e1a9da6a1a529b089d", null ],
      [ "KEY_DOWN", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22baa9cdac7967bf7d88fdb761138a2a3416", null ],
      [ "KEY_PAGEUP", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba5d9c9ba1d8f2c6f6737db37d3f449071", null ],
      [ "KEY_PAGEDOWN", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba5996c34d86df2b3c1be741aeb35bdbc4", null ],
      [ "KEY_SELECT", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba3b37a163628bc7015aac5efab4a66ef5", null ],
      [ "KEY_PRINT", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22baf6ff54b9651ca18045e4000c2d26f790", null ],
      [ "KEY_ENTER", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba2a662d23aadd7106a3a2afdfd5d426ed", null ],
      [ "KEY_SNAPSHOT", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22bacc39d60a35433541177dbd7bf01a8257", null ],
      [ "KEY_INSERT", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba26f2c18a3a0a7eabf7bd11f0ec93be78", null ],
      [ "KEY_DELETE", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22bae7a3a4540031b038014294aa6743a7a4", null ],
      [ "KEY_HELP", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22bad729e81b40a3acb64b5a40b7fa459b09", null ],
      [ "KEY_NUMPAD0", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba55aef83f557c4ed24e2847d38ea292b3", null ],
      [ "KEY_NUMPAD1", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba681b5574363c5d5a463af7e514172292", null ],
      [ "KEY_NUMPAD2", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba779490ca3da209736187a912cd8382dc", null ],
      [ "KEY_NUMPAD3", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22bae58753ec4558e7b68f4aa07ed97d50d7", null ],
      [ "KEY_NUMPAD4", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba744226502b73227ed219a5142c232126", null ],
      [ "KEY_NUMPAD5", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba906fbf3011cae4b931d6fe6126147a82", null ],
      [ "KEY_NUMPAD6", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22bac4e7f0a72c3594aa3d5b83f61b714e3f", null ],
      [ "KEY_NUMPAD7", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22bae6d134db5bf54ae1d4b29f8a2cca8889", null ],
      [ "KEY_NUMPAD8", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba258d226c87d8446423d3214a59eb498b", null ],
      [ "KEY_NUMPAD9", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba6ab9d27201ffbdccabde9f5a0e9dedd9", null ],
      [ "KEY_MULTIPLY", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22baa7ccd4f6c9a10fe36e0e7bd28d15bea3", null ],
      [ "KEY_ADD", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba88535ed64ae437ce31620dcb62c66c9e", null ],
      [ "KEY_SEPARATOR", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba79459423b8bbe9f70949f464cd7a27ae", null ],
      [ "KEY_SUBTRACT", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22baf6ba424919235c2cbbac7184e3625395", null ],
      [ "KEY_DECIMAL", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22bafce663586a7e53223158c5f4ce6033fc", null ],
      [ "KEY_DIVIDE", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba36a890023ae628d5c36ca010edffc59c", null ],
      [ "KEY_F1", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22bafcf70bc39c0032de8a1c6452ac9860a5", null ],
      [ "KEY_F2", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba87897fd25282941e1a9bf72b9f64559a", null ],
      [ "KEY_F3", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba965c99b1f4fc05cec09ef61b0af8e74a", null ],
      [ "KEY_F4", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba01bce78a73ad136a7b42941297aff373", null ],
      [ "KEY_F5", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba6a69ea34f5d1372692bf040637e57c8f", null ],
      [ "KEY_F6", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba247a20a9998f080827dd34004abc2f9a", null ],
      [ "KEY_F7", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba34a07203a0a4f3e996b44e9a4fcfd1c6", null ],
      [ "KEY_F8", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba9eaf4e9e3d8451fd1332c013d12c1375", null ],
      [ "KEY_F9", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba160e82eea885870bfa4924c27040cd7f", null ],
      [ "KEY_F10", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba3b922025c26b38585ab140c7e40b291c", null ],
      [ "KEY_F11", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22bad54743bc4e7f9279abf671cc2a091ce1", null ],
      [ "KEY_F12", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba835f8397baa58fd73ff9c268d6458add", null ],
      [ "KEY_NUMLOCK", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22baa98feaa9c2c57dc8e7b04cb8fddc1a61", null ],
      [ "KEY_SCROLL", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba10db988ee4f813d95a5b7cd2f96e3c48", null ],
      [ "KEY_SHIFT", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba7d538b177ab06797012e9ffb1449acd9", null ],
      [ "KEY_CONTROL", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba48f64be40a1a166f83ec1cab14da6bdc", null ],
      [ "KEY_ALT", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22baf22ac608afcf783bb841f664a2620ca6", null ],
      [ "KEY_EQUALS", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22baf97f0846e149da44bbf962fa75680809", null ],
      [ "KEY_CONTEXTMENU", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba1992687fd833d3503080861864624e25", null ],
      [ "KEY_MEDIA_PLAY", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba6322842e54ea558c670690f2715b45fb", null ],
      [ "KEY_MEDIA_STOP", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22baad3b9b6fd66ddf211586428be4479c43", null ],
      [ "KEY_MEDIA_PREV", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba29d798af827489cf5ab68c378b8a7ac8", null ],
      [ "KEY_MEDIA_NEXT", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22bac80fc1b18bda12f7dfccbbe1b012798b", null ],
      [ "KEY_VOLUME_UP", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22baedbb585f9e7ee87263a250c91542fb02", null ],
      [ "KEY_VOLUME_DOWN", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba2304f457aba66febcf852dbf1cbae8b0", null ],
      [ "KEY_F13", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba29161713f30649423d0ddefa16028396", null ],
      [ "KEY_F14", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba7a39de2eb466cf269a7a34d0377cf326", null ],
      [ "KEY_F15", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba57efdf8b5659ceaf5bda4be62e65ab56", null ],
      [ "KEY_F16", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22baabf57281e043880eb269a6a72368aca5", null ],
      [ "KEY_F17", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba5ce646467129e626c1ec8888f80045ed", null ],
      [ "KEY_F18", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22bab6e856fc1ebc35abda65fd30fe9deeca", null ],
      [ "KEY_F19", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22baa385ff09ff5f05a4fedb1e75570baa8b", null ],
      [ "KEY_F20", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22baa1947110c50dcb6219308bb1624d43ff", null ],
      [ "KEY_F21", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba3a2ee9ec4d7c44239e3f9f769074ac02", null ],
      [ "KEY_F22", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba2526eb7f49c98dd552cbd5504ad30f4a", null ],
      [ "KEY_F23", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22bade95d1029378c795a6ebe6213f913a2c", null ],
      [ "KEY_F24", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba42c003270834bebc8dd3e64ec5ae8693", null ],
      [ "KEY_SUPER", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22baf6db7ad5110a115d774dd8d74d333a42", null ],
      [ "VKEY_FIRST_CODE", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba0abb06f320e406fbe76c08b2f5909ad6", null ],
      [ "VKEY_LAST_CODE", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba219b7884c92935dc6365a7fec8b55bcf", null ],
      [ "VKEY_FIRST_ASCII", "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22ba39f030dbc1bfdb4a14a310acc744178f", null ]
    ] ],
    [ "KeyModifier", "namespaceSteinberg.html#a743f60968fa58cdae68b31a1a3eb493d", [
      [ "kShiftKey", "namespaceSteinberg.html#a743f60968fa58cdae68b31a1a3eb493da7dee5096e7803ac26cee7abe740d777d", null ],
      [ "kAlternateKey", "namespaceSteinberg.html#a743f60968fa58cdae68b31a1a3eb493da8779d8eaee888493c6c5db7acc5d4a0a", null ],
      [ "kCommandKey", "namespaceSteinberg.html#a743f60968fa58cdae68b31a1a3eb493da111880e47a70791b129ec7a46f988078", null ],
      [ "kControlKey", "namespaceSteinberg.html#a743f60968fa58cdae68b31a1a3eb493da6bd5ac36e7d960d29783e07406f3b15c", null ]
    ] ],
    [ "StandardColor", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cd", [
      [ "kBlack", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda84bb4627f551fc5ff2d9aedb8f3b4947", null ],
      [ "kWhite", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda9e1b2d3dcb56c17a372440853228ad01", null ],
      [ "kGray5", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda02a9193b86afaccf9bbf742a323100be", null ],
      [ "kGray10", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda071b3be3908931dc26e8743b00ffde8d", null ],
      [ "kGray20", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda1e226959be1359aaaa71395aa86f8208", null ],
      [ "kGray30", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda5ff656d817dae9754566238d59d39157", null ],
      [ "kGray40", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda8bdc572a21805c3161278f91a3530712", null ],
      [ "kGray50", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda9db2b60f76d6b83e56c35985b4b9205c", null ],
      [ "kGray60", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdadab15681c7200799430d2f338d0ed61e", null ],
      [ "kGray70", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda0354ed8af3577ebdf208137b26843594", null ],
      [ "kGray80", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda1928cdb81e838319f6953a0c49d64c28", null ],
      [ "kGray90", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda63b585983725a29a14552acb823a2949", null ],
      [ "kRed", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda5a655b1a02e5b0311571ca57ce4f3900", null ],
      [ "kLtRed", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdaa03531f6aa4608be014e3f8a8112f49d", null ],
      [ "kDkRed", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda56b755177db5009ab61067b96229a9be", null ],
      [ "kGreen", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda8ea4b941d1d41f4bd88387c38e13e9d3", null ],
      [ "kLtGreen", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdac772acbace7fe195180ec04b0db54e3d", null ],
      [ "kDkGreen", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdad38f804f1c4b123fe442f81576461515", null ],
      [ "kBlue", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdaab48c32302f7159d81e081c41dc2d3d2", null ],
      [ "kLtBlue", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda133f1956c6567e805341ce1753a03d28", null ],
      [ "kDkBlue", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda6837b9736b787405dbed0a9d532eaf90", null ],
      [ "kMagenta", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda951e8c9c29427097fd137e19a3300e03", null ],
      [ "kLtMagenta", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda96ec73e5e8ede13098c92ca3b14c7c43", null ],
      [ "kDkMagenta", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda1c83f6d971da4f2cb0a97fe97d1f34b5", null ],
      [ "kYellow", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdac05df1f876c243e8f60ea03a9f866b80", null ],
      [ "kLtYellow", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdae22e7268faee0570b14aa13c801fa3b9", null ],
      [ "kDkYellow", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda4943112719ee8d66b8de5b8f88ccd8ce", null ],
      [ "kOrange", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda6ad203278f32dfcc959be28888e52582", null ],
      [ "kLtOrange", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdaf35707aff5cbf5d69b5f0aecd302d9b1", null ],
      [ "kDkOrange", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda5fe89a70ee7bcac01feb5fc1de15985f", null ],
      [ "kGold", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda14ef40d42e6bb88349bc9ad97aed7bdb", null ],
      [ "kBlack50", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda186d906a7af8fff76bff867913a7969f", null ],
      [ "kBlack70", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda64b4e2e55e8f2bd3d9759ad520723121", null ],
      [ "kNumStandardColors", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda020c41a39f7c676ecb89ee23885070b6", null ],
      [ "kLtGray", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdac4512c2e2b20209b3fa8364b8be3483d", null ],
      [ "kGray", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda1ab75347fd43308dc34268db5a181108", null ],
      [ "kDkGray", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda78c5cc590de98a677b2dc3076c904128", null ]
    ] ],
    [ "_tstrlen", "namespaceSteinberg.html#a919216f5d1c976556c67d94c8522db43", null ],
    [ "tstrlen", "namespaceSteinberg.html#adee0831ed9db758b6d119bf3c3b99e43", null ],
    [ "strlen8", "namespaceSteinberg.html#a8a76499e90e8d7f44ff14f18f129afcd", null ],
    [ "strlen16", "namespaceSteinberg.html#af722fba1489836fd17c0f50206e8e262", null ],
    [ "_tstrcmp", "namespaceSteinberg.html#a290312f8c692123017dfd6ab276f7148", null ],
    [ "tstrcmp", "namespaceSteinberg.html#a532f4daa08250b5344c193d5ab179454", null ],
    [ "strcmp8", "namespaceSteinberg.html#a6b08a8f4a4993d488e14cf812807675c", null ],
    [ "strcmp16", "namespaceSteinberg.html#a9d769cee1cea3e2224b7c2fb9c61e1cb", null ],
    [ "strcmpT", "namespaceSteinberg.html#a485a5d44628dff8b69863742f214ef8c", null ],
    [ "strcmpT< char8 >", "namespaceSteinberg.html#a9c04924e4e7bafc6162173aa938ce7ae", null ],
    [ "strcmpT< char16 >", "namespaceSteinberg.html#ace46dac211111d8384286b1ae2c9689e", null ],
    [ "_tstrncmp", "namespaceSteinberg.html#a59846763a52e0e182dcf5b1573a7e89e", null ],
    [ "tstrncmp", "namespaceSteinberg.html#accf894d033204ed519ac2612a46c442d", null ],
    [ "strncmp8", "namespaceSteinberg.html#a95aadb22dc3e307e7e65db901e771f60", null ],
    [ "strncmp16", "namespaceSteinberg.html#a91005f5c2c5b338136cf19c7afec6064", null ],
    [ "strncmpT", "namespaceSteinberg.html#a78350a628df86c106340f08c57f9b8b5", null ],
    [ "strncmpT< char8 >", "namespaceSteinberg.html#a18016e0ec944a4149fab9503980332e7", null ],
    [ "strncmpT< char16 >", "namespaceSteinberg.html#a154d134fd010929649c537c38e9937f8", null ],
    [ "_tstrcpy", "namespaceSteinberg.html#ac6ae1990a6eb57a92f18013ab200fd61", null ],
    [ "tstrcpy", "namespaceSteinberg.html#a46784fedcaf2cd10c9a0f2614ecdb832", null ],
    [ "strcpy8", "namespaceSteinberg.html#a79cc5b78e482b56ee792dac1fa4ddc1b", null ],
    [ "strcpy16", "namespaceSteinberg.html#a1f2971e00b71425e2035c4f946031fd9", null ],
    [ "_tstrncpy", "namespaceSteinberg.html#a901c5dcbc48f4a6f220bd7d4d5d93c66", null ],
    [ "tstrncpy", "namespaceSteinberg.html#a663277a04cd2cb23fd812715359350f5", null ],
    [ "strncpy8", "namespaceSteinberg.html#a125a36f7e942e2b77d76d57d2cc6398d", null ],
    [ "strncpy16", "namespaceSteinberg.html#ad1477e38cb33dbf399ba506dd9fa1ab2", null ],
    [ "_tstrcat", "namespaceSteinberg.html#a84be4b87ef6295be6b4ea97052b94999", null ],
    [ "tstrcat", "namespaceSteinberg.html#ad878d42e7b5a81c513f613c52a5f9f0a", null ],
    [ "strcat8", "namespaceSteinberg.html#a37115f1ed1a36ba151d84ff370aaf05f", null ],
    [ "strcat16", "namespaceSteinberg.html#a05fbb76593f6044ac8375e1becf16d4d", null ],
    [ "str8ToStr16", "namespaceSteinberg.html#a65d41e28de7b3ce39de0f9e2e6d99926", null ],
    [ "FIDStringsEqual", "namespaceSteinberg.html#afcb1a763178c9806cc827360a02741e2", null ],
    [ "strEmpty", "namespaceSteinberg.html#a6a838f230987e1a095b0cb75c28d4a65", null ],
    [ "str8Empty", "namespaceSteinberg.html#a728f0ddc16a12be5fa0f950f4c8a0a8e", null ],
    [ "str16Empty", "namespaceSteinberg.html#a81eef9745d0b6653c6a1c78bb89533d8", null ],
    [ "getTUID", "namespaceSteinberg.html#ab5c714b140d499f304e042e746ca9b1b", null ],
    [ "Min", "namespaceSteinberg.html#a29948ccdc9190054dba415d7ac893768", null ],
    [ "Max", "namespaceSteinberg.html#ae861849d924547696801cead672d8b16", null ],
    [ "Abs", "namespaceSteinberg.html#a6618cd408bb7e6ca706d2ede559b7883", null ],
    [ "Sign", "namespaceSteinberg.html#a89abcadbf71668d5248488e4b94eacc6", null ],
    [ "Bound", "namespaceSteinberg.html#ac5974f8c0577e9e37f9ea9d9d5a70a75", null ],
    [ "Swap", "namespaceSteinberg.html#a1bab287b1f45fc8d99493a1d142b7deb", null ],
    [ "IsApproximateEqual", "namespaceSteinberg.html#a004e46ded0d442c0c031094559ad23b6", null ],
    [ "ToNormalized", "namespaceSteinberg.html#a31a33bd1d2143601be9244b5eb666167", null ],
    [ "FromNormalized", "namespaceSteinberg.html#a53b9fdb1691391567d0bd6697ddc503c", null ],
    [ "operator==", "namespaceSteinberg.html#a8a42998c5c8a3a844cdf3b21d1b9be70", null ],
    [ "operator!=", "namespaceSteinberg.html#a443dbd34922bff48d94a4060764ae9e9", null ],
    [ "VirtualKeyCodeToChar", "namespaceSteinberg.html#abb64176847a23e106203af14083e1827", null ],
    [ "CharToVirtualKeyCode", "namespaceSteinberg.html#a9a49a1a97b367d7069b1f6515261fe3e", null ],
    [ "owned", "namespaceSteinberg.html#a603b2ada00778d1a71caef40362ae6d8", null ],
    [ "shared", "namespaceSteinberg.html#aecbafba4ac9e0f4734fdc1d0aecc5f70", null ],
    [ "MakeColorSpec", "namespaceSteinberg.html#a58b97116e0faaf335c798a65b687e9f2", null ],
    [ "MakeColorSpec", "namespaceSteinberg.html#aa7cb190cb494b7f61aaacf170d322d30", null ],
    [ "GetBlue", "namespaceSteinberg.html#a25a9f00585fee6f2dda46514bb29b933", null ],
    [ "GetGreen", "namespaceSteinberg.html#a7daea0aeaaf968f0cbc3473815ef4c4c", null ],
    [ "GetRed", "namespaceSteinberg.html#a7deed6801721823ffd280717b6675c48", null ],
    [ "GetAlpha", "namespaceSteinberg.html#a7ef9ebfedc0532d783ae68dbbe8f08c7", null ],
    [ "SetBlue", "namespaceSteinberg.html#a145379c6e26917acaa0bac72b8c0bc05", null ],
    [ "SetGreen", "namespaceSteinberg.html#ae8f11c779bd10486d527d1a7142d8e6b", null ],
    [ "SetRed", "namespaceSteinberg.html#a69a06ce98bc91e355a0b3f558344b0f2", null ],
    [ "SetAlpha", "namespaceSteinberg.html#aabd2ebacd043630aac6ea6383bace10b", null ],
    [ "NormalizeColorComponent", "namespaceSteinberg.html#aa50131d71c879a95dfa3efac24b815c6", null ],
    [ "DenormalizeColorComponent", "namespaceSteinberg.html#abad8045987a3d33b9421e724c06a9d6f", null ],
    [ "SetAlphaNorm", "namespaceSteinberg.html#a272ecb0af547f0b5e960144874fc8027", null ],
    [ "GetAlphaNorm", "namespaceSteinberg.html#a572daddd6ee8f61011dcd066eef99b0c", null ],
    [ "NormalizeAlpha", "namespaceSteinberg.html#a170abdd6288ad80f6ddca3d7e9c3fb59", null ],
    [ "DenormalizeAlpha", "namespaceSteinberg.html#abfe74133ed684fa31c7227a9d1a4b3ce", null ],
    [ "StripAlpha", "namespaceSteinberg.html#a27f6f9da6429b67343a7e36078494bd9", null ],
    [ "BlendColor", "namespaceSteinberg.html#a82f9ae0460c5ad8b348cdfa75fec5c68", null ],
    [ "StringCopy", "namespaceSteinberg.html#a51c63740ab18a5e8a1394fb10e743917", null ],
    [ "StringLength", "namespaceSteinberg.html#ae6cdc2936b352ab9cd2fb6aed350bbaa", null ],
    [ "kPlatformStringWin", "namespaceSteinberg.html#a2ae80314db54c6bda33e1cf922effb47", null ],
    [ "kPlatformStringMac", "namespaceSteinberg.html#ad5ffc071fd688ac833b5283777037278", null ],
    [ "kPlatformStringIOS", "namespaceSteinberg.html#a0e747a3b854268949a75a1c8e8fd070c", null ],
    [ "kPlatformStringLinux", "namespaceSteinberg.html#a1c13255fbcd5845d44bd45cc27bd3586", null ],
    [ "kPlatformString", "namespaceSteinberg.html#a45a730ec762ad31ab0e5c80e15560afc", null ],
    [ "kPlatformTypeHWND", "namespaceSteinberg.html#aa1e68ac1f25da9c85c937d0360dbc601", null ],
    [ "kPlatformTypeHIView", "namespaceSteinberg.html#a974cabea219cb31ad8218ba15d1f7071", null ],
    [ "kPlatformTypeNSView", "namespaceSteinberg.html#a8ce69944b5475d65206469b9ebcbf755", null ],
    [ "kPlatformTypeUIView", "namespaceSteinberg.html#a6362a7ca65b87d30c561dac986b757bd", null ],
    [ "kPlatformTypeX11EmbedWindowID", "namespaceSteinberg.html#ac945decc5f26f3fdb5419e8de833a0e1", null ]
];